SchemaParser class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
extractSchema(
SchemaNode node) → Map< String, dynamic> -
getAllPaths(
SchemaNode node, {String prefix = ''}) → List< String> -
getValueAtPath(
SchemaNode node, String path) → dynamic -
parse(
dynamic input) → SchemaNode -
parseWithValidation(
dynamic input, {bool allowNull = true, bool requireObject = false}) → SchemaNode -
toJsonString(
SchemaNode node, {bool pretty = false}) → String